@@ -417,7 +417,22 @@ int net_open_socket(const char *hostname, int port, int timeout, int *ret_fd,
     int fd;
     struct sockaddr_in sock;
     struct hostent *remote_host;
+#ifdef __MINGW32__
+    unsigned long inaddr;
+#endif /* __MINGW32__ */
     
+#ifdef __MINGW32__
+    /* Work around a broken gethostbyname() function on old Windows systems that
+     * cannot handle IP addresses. */
+    if ((inaddr = inet_addr(hostname)) != INADDR_NONE
+	    && (remote_host = gethostbyaddr((char *)(&inaddr), 
+		    sizeof(unsigned long), AF_INET)) != NULL)
+    {
+	/* 'hostname' contains an IP address that was successfully converted to
+	 * a struct hostent. No need to call gethostbyname() anymore. */
+    }
+    else
+#endif /* __MINGW32__ */
     if (!(remote_host = gethostbyname(hostname)))
     {
 	snprintf(errstr, errstr_bufsize, "cannot locate host %s: %s", hostname,
@@ -463,7 +478,7 @@ int net_open_socket(const char *hostname, int port, int timeout, int *ret_fd,
     *ret_fd = fd;
     return NET_EOK;
 
-#endif /* HAVE_GETADDRINFO */
+#endif /* !HAVE_GETADDRINFO */
 }
 
 
@@ -485,7 +500,7 @@ void net_readbuf_init(net_readbuf_t *readbuf)
  * Wraps read() to provide buffering for net_gets().
  */
 
-ssize_t net_readbuf_read(int fd, net_readbuf_t *readbuf, char *ptr, 
+int net_readbuf_read(int fd, net_readbuf_t *readbuf, char *ptr, 
 	char *errstr)
 {
     if (readbuf->count <= 0)
@@ -495,7 +510,8 @@ ssize_t net_readbuf_read(int fd, net_readbuf_t *readbuf, char *ptr,
 #else /* ! __MINGW32__ */
 	do
 	{
-	    readbuf->count = recv(fd, readbuf->buf, sizeof(readbuf->buf), 0);
+	    readbuf->count = (int)recv(fd, readbuf->buf, 
+		    sizeof(readbuf->buf), 0);
 	}
 	while (readbuf->count < 0 && errno == EINTR);
 #endif /* ! __MINGW32__ */
@@ -533,7 +549,7 @@ int net_gets(int fd, net_readbuf_t *readbuf,
 {
     char c;
     size_t i;
-    ssize_t ret;
+    int ret;
 
     i = 0;
     while (i + 1 < size)
