@@ -517,11 +517,6 @@ int check_secure(const char *pathname, char *errstr)
 	return PATHS_EUNKNOWN;
     }
     
-    if (!S_ISREG(statbuf.st_mode))
-    {
-	snprintf(errstr, errstr_bufsize, "must be a regular file");
-	return PATHS_EINSECURE;
-    }
     if (statbuf.st_mode & (S_IXUSR | S_IRGRP | S_IWGRP | S_IXGRP 
 		| S_IROTH | S_IWOTH | S_IXOTH))
     {
