@@ -262,7 +262,8 @@ int smtp_put(smtp_server_t *srv, const char *s, size_t len, int newline,
 #ifdef HAVE_SSL
     if (tls_is_active(&srv->tls))
     {
-	if (tls_puts(&srv->tls, s, len, errstr) == TLS_EOK && newline)
+	e = (tls_puts(&srv->tls, s, len, errstr) != TLS_EOK);
+	if (!e && newline)
 	{
 	    e = (tls_puts(&srv->tls, "\r\n", 2, errstr) != TLS_EOK);
 	}
@@ -270,7 +271,8 @@ int smtp_put(smtp_server_t *srv, const char *s, size_t len, int newline,
     else
     {
 #endif /* HAVE_SSL */
-	if (net_puts(srv->fd, s, len, errstr) == NET_EOK && newline)
+	e = (net_puts(srv->fd, s, len, errstr) != NET_EOK);
+	if (!e && newline)
 	{
 	    e = (net_puts(srv->fd, "\r\n", 2, errstr) != NET_EOK);
 	}
